Bootstrap-session-timeout - Basic Usage

# Bootstrap-session-timeout

## Basic Usage

Shows the warning dialog after 3 seconds. If user takes no action (interacts with the page in any way), browser is redirected to redirUrl. On any user action (mouse, keyboard or touch) the timeout timer is reset.

                $.sessionTimeout({
                    keepAliveUrl: 'keep-alive.html',
                    logoutUrl: 'login.html',
                    redirUrl: 'locked.html',
                    warnAfter: 3000,
                    redirAfter: 10000
                });

Back to Demo Index